/*
**	termARexxData.c
**
**	Declarations for ARexx interface data
**
**	Copyright  1990-1993 by Olaf `Olsen' Barthel & MXM
**		All Rights Reserved
*/

#include "termARexxGlobal.h"
#include "termARexxAttributes.h"

STATIC STRPTR ParityMappings[] =
{
	"NONE",
	"EVEN",
	"ODD",
	"MARK",
	"SPACE",
	NULL
};

STATIC STRPTR HandshakingMappings[] =
{
	"NONE",
	"RTSCTS",
	"RTSCTSDSR",
	NULL
};

STATIC STRPTR DuplexMappings[] =
{
	"FULL",
	"HALF",
	NULL
};

STATIC STRPTR ColourMappings[] =
{
	"FOUR",
	"EIGHT",
	"SIXTEEN",
	"TWO",
	NULL
};

STATIC STRPTR StatusMappings[] =
{
	"DISABLED",
	"STANDARD",
	"COMPRESSED",
	NULL
};

STATIC STRPTR BellMappings[] =
{
	"NONE",
	"VISIBLE",
	"AUDIBLE",
	"BOTH",
	"SYSTEM",
	NULL
};

STATIC STRPTR AlertMappings[] =
{
	"NONE",
	"BELL",
	"SCREEN",
	"BOTH",
	NULL
};

STATIC STRPTR EmulationMappings[] =
{
	"INTERNAL",
	"ATOMIC",
	"TTY",
	"EXTERNAL",
	"HEX",
	NULL
};

STATIC STRPTR FontMappings[] =
{
	"STANDARD",
	"IBM",
	"IBMRAW",
	NULL
};

STATIC STRPTR CRMappings[] =
{
	"IGNORE",
	"CR",
	"CRLF",
	NULL
};

STATIC STRPTR LFMappings[] =
{
	"IGNORE",
	"LF",
	"LFCR",
	NULL
};

STATIC STRPTR IdentifyMappings[] =
{
	"IGNORE",
	"FILETYPE",
	"SOURCE",
	NULL
};

STATIC STRPTR ApplicationMappings[] =
{
	"STANDARD",
	"APPLICATION",
	NULL
};

STATIC STRPTR FontScaleMappings[] =
{
	"NORMAL",
	"HALF",
	NULL
};

STATIC STRPTR ScrollMappings[] =
{
	"JUMP",
	"SMOOTH",
	NULL
};

STATIC STRPTR SexMappings[] =
{
	"MALE",
	"FEMALE",
	NULL
};

STATIC STRPTR OnlineMappings[] =
{
	"TIME",
	"COST",
	"BOTH",
	NULL
};

STATIC STRPTR AutoDateMappings[] =
{
	"NAME",
	"INCLUDE",
	NULL
};

STATIC STRPTR PacingMappings[] =
{
	"DIRECT",
	"ECHO",
	"ANYECHO",
	"PROMPT",
	"DELAY",
	"KEYBOARD",
	NULL
};

STATIC STRPTR OpenBufferMappings[] =
{
	"TOP",
	"END",
	NULL
};

STATIC STRPTR BufferPositionMappings[] =
{
	"LEFT",
	"MID",
	"RIGHT",
	NULL
};

struct AttributeEntry AttributeTable[] =
{
	0,	"TERM",				INFO_STEM,	TRUE,	NULL,			ATTR_APPLICATION,

	1,	 "VERSION",			INFO_TEXT,	TRUE,	NULL,			ATTR_APPLICATION_VERSION,
	1,	 "SCREEN",			INFO_TEXT,	TRUE,	NULL,			ATTR_APPLICATION_SCREEN,

	1,	 "SESSION",			INFO_STEM,	TRUE,	NULL,			ATTR_APPLICATION_SESSION,
	2,	  "ONLINE",			INFO_BOOLEAN,	TRUE,	NULL,			ATTR_APPLICATION_SESSION_ONLINE,
	2,	  "SESSIONSTART",		INFO_TEXT,	TRUE,	NULL,			ATTR_APPLICATION_SESSION_SESSIONSTART,
	2,	  "BYTESSENT",			INFO_NUMERIC,	TRUE,	NULL,			ATTR_APPLICATION_SESSION_BYTESSENT,
	2,	  "BYTESRECEIVED",		INFO_NUMERIC,	TRUE,	NULL,			ATTR_APPLICATION_SESSION_BYTESRECEIVED,
	2,	  "CONNECTMESSAGE",		INFO_TEXT,	TRUE,	NULL,			ATTR_APPLICATION_SESSION_CONNECTMESSAGE,
	2,	  "BBSNAME",			INFO_TEXT,	TRUE,	NULL,			ATTR_APPLICATION_SESSION_BBSNAME,
	2,	  "BBSNUMBER",			INFO_TEXT,	TRUE,	NULL,			ATTR_APPLICATION_SESSION_BBSNUMBER,
	2,	  "BBSCOMMENT",			INFO_TEXT,	TRUE,	NULL,			ATTR_APPLICATION_SESSION_BBSCOMMENT,
	2,	  "USERNAME",			INFO_TEXT,	TRUE,	NULL,			ATTR_APPLICATION_SESSION_USERNAME,
	2,	  "ONLINEMINUTES",		INFO_NUMERIC,	TRUE,	NULL,			ATTR_APPLICATION_SESSION_ONLINEMINUTES,
	2,	  "ONLINECOST",			INFO_NUMERIC,	TRUE,	NULL,			ATTR_APPLICATION_SESSION_ONLINECOST,

	1,	 "AREXX",			INFO_TEXT,	TRUE,	NULL,			ATTR_APPLICATION_AREXX,
	1,	 "LASTERROR",			INFO_NUMERIC,	TRUE,	NULL,			ATTR_APPLICATION_LASTERROR,

	1,	 "TERMINAL",			INFO_STEM,	TRUE,	NULL,			ATTR_APPLICATION_TERMINAL,
	2,	  "ROWS",			INFO_NUMERIC,	TRUE,	NULL,			ATTR_APPLICATION_TERMINAL_ROWS,
	2,	  "COLUMNS",			INFO_NUMERIC,	TRUE,	NULL,			ATTR_APPLICATION_TERMINAL_COLUMNS,

	1,	 "BUFFER",			INFO_STEM,	TRUE,	NULL,			ATTR_APPLICATION_BUFFER,
	2,	  "SIZE",			INFO_NUMERIC,	TRUE,	NULL,			ATTR_APPLICATION_BUFFER_SIZE,

	0,	"SERIALPREFS",			INFO_STEM,	FALSE,	NULL,			ATTR_PREFS_SERIAL,
	1,	 "BAUDRATE",			INFO_NUMERIC,	FALSE,	NULL,			ATTR_PREFS_SERIAL_BAUDRATE,
	1,	 "BREAKLENGTH",			INFO_NUMERIC,	FALSE,	NULL,			ATTR_PREFS_SERIAL_BREAKLENGTH,
	1,	 "BUFFERSIZE",			INFO_NUMERIC,	FALSE,	NULL,			ATTR_PREFS_SERIAL_BUFFERSIZE,
	1,	 "DEVICENAME",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_SERIAL_DEVICENAME,
	1,	 "UNIT",			INFO_NUMERIC,	FALSE,	NULL,			ATTR_PREFS_SERIAL_UNIT,
	1,	 "BITSPERCHAR",			INFO_NUMERIC,	FALSE,	NULL,			ATTR_PREFS_SERIAL_BITSPERCHAR,
	1,	 "PARITYMODE",			INFO_MAPPED,	FALSE,	ParityMappings,		ATTR_PREFS_SERIAL_PARITYMODE,
	1,	 "STOPBITS",			INFO_NUMERIC,	FALSE,	NULL,			ATTR_PREFS_SERIAL_STOPBITS,
	1,	 "HANDSHAKINGMODE",		INFO_MAPPED,	FALSE,	HandshakingMappings,	ATTR_PREFS_SERIAL_HANDSHAKINGMODE,
	1,	 "DUPLEXMODE",			INFO_MAPPED,	FALSE,	DuplexMappings,		ATTR_PREFS_SERIAL_DUPLEXMODE,
	1,	 "XONXOFF",			INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_SERIAL_XONXOFF,
	1,	 "HIGHSPEED",			INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_SERIAL_HIGHSPEED,
	1,	 "SHARED",			INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_SERIAL_SHARED,
	1,	 "STRIPBIT8",			INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_SERIAL_STRIPBIT8,
	1,	 "CARRIERCHECK",		INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_SERIAL_CARRIERCHECK,
	1,	 "PASSXONXOFFTHROUGH",		INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_SERIAL_PASSXONXOFFTHROUGH,
	1,	 "QUANTUM",			INFO_NUMERIC,	FALSE,	NULL,			ATTR_PREFS_SERIAL_QUANTUM,

	0,	"MODEMPREFS",			INFO_STEM,	FALSE,	NULL,			ATTR_PREFS_MODEM,
	1,	 "MODEMINITTEXT",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_MODEM_MODEMINITTEXT,
	1,	 "MODEMEXITTEXT",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_MODEM_MODEMEXITTEXT,
	1,	 "MODEMHANGUPTEXT",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_MODEM_MODEMHANGUPTEXT,
	1,	 "DIALPREFIXTEXT",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_MODEM_DIALPREFIXTEXT,
	1,	 "DIALSUFFIXTEXT",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_MODEM_DIALSUFFIXTEXT,
	1,	 "NOCARRIERTEXT",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_MODEM_NOCARRIERTEXT,
	1,	 "NODIALTONETEXT",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_MODEM_NODIALTONETEXT,
	1,	 "CONNECTTEXT",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_MODEM_CONNECTTEXT,
	1,	 "VOICETEXT",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_MODEM_VOICETEXT,
	1,	 "RINGTEXT",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_MODEM_RINGTEXT,
	1,	 "BUSYTEXT",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_MODEM_BUSYTEXT,
	1,	 "OKTEXT",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_MODEM_OKTEXT,
	1,	 "ERRORTEXT",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_MODEM_ERRORTEXT,
	1,	 "REDIALDELAY",			INFO_NUMERIC,	FALSE,	NULL,			ATTR_PREFS_MODEM_REDIALDELAY,
	1,	 "DIALRETRIES",			INFO_NUMERIC,	FALSE,	NULL,			ATTR_PREFS_MODEM_DIALRETRIES,
	1,	 "DIALTIMEOUT",			INFO_NUMERIC,	FALSE,	NULL,			ATTR_PREFS_MODEM_DIALTIMEOUT,
	1,	 "CONNECTAUTOBAUD",		INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_MODEM_CONNECTAUTOBAUD,
	1,	 "HANGUPDROPSDTR",		INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_MODEM_HANGUPDROPSDTR,
	1,	 "REDIALAFTERHANGUP",		INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_MODEM_REDIALAFTERHANGUP,
	1,	 "NOCARRIERISBUSY",		INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_MODEM_NOCARRIERISBUSY,
	1,	 "CONNECTLIMIT",		INFO_NUMERIC,	FALSE,	NULL,			ATTR_PREFS_MODEM_CONNECTLIMIT,
	1,	 "CONNECTLIMITMACRO",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_MODEM_CONNECTLIMITMACRO,
	1,	 "TIMETOCONNECT",		INFO_NUMERIC,	FALSE,	NULL,			ATTR_PREFS_MODEM_TIME_TO_CONNECT,

	0,	"COMMANDPREFS",			INFO_STEM,	FALSE,	NULL,			ATTR_PREFS_COMMANDS,
	1,	 "STARTUPMACROTEXT",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_COMMANDS_STARTUPMACROTEXT,
	1,	 "LOGOFFMACROTEXT",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_COMMANDS_LOGOFFMACROTEXT,
	1,	 "UPLOADMACROTEXT",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_COMMANDS_UPLOADMACROTEXT,
	1,	 "DOWNLOADMACROTEXT",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_COMMANDS_DOWNLOADMACROTEXT,

	0,	"SCREENPREFS",			INFO_STEM,	FALSE,	NULL,			ATTR_PREFS_SCREEN,
	1,	 "COLOURMODE",			INFO_MAPPED,	FALSE,	ColourMappings,		ATTR_PREFS_SCREEN_COLOURMODE,
	1,	 "FONTNAME",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_SCREEN_FONTNAME,
	1,	 "FONTSIZE",			INFO_NUMERIC,	FALSE,	NULL,			ATTR_PREFS_SCREEN_FONTSIZE,
	1,	 "MAKESCREENPUBLIC",		INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_SCREEN_MAKESCREENPUBLIC,
	1,	 "SHANGHAIWINDOWS",		INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_SCREEN_SHANGHAIWINDOWS,
	1,	 "BLINKING",			INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_SCREEN_BLINKING,
	1,	 "FASTERLAYOUT",		INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_SCREEN_FASTERLAYOUT,
	1,	 "TITLEBAR",			INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_SCREEN_TITLEBAR,
	1,	 "STATUSLINEMODE",		INFO_MAPPED,	FALSE,	StatusMappings,		ATTR_PREFS_SCREEN_STATUSLINEMODE,
	1,	 "USEPUBSCREEN",		INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_SCREEN_USEWORKBENCH,
	1,	 "PUBSCREENNAME",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_SCREEN_PUBSCREENNAME,
	1,	 "ONLINEDISPLAY",		INFO_MAPPED,	FALSE,	OnlineMappings,		ATTR_PREFS_SCREEN_ONLINEDISPLAY,

	0,	"TERMINALPREFS",		INFO_STEM,	FALSE,	NULL,			ATTR_PREFS_TERMINAL,
	1,	 "BELLMODE",			INFO_MAPPED,	FALSE,	BellMappings,		ATTR_PREFS_TERMINAL_BELLMODE,
	1,	 "ALERTMODE",			INFO_MAPPED,	FALSE,	AlertMappings,		ATTR_PREFS_TERMINAL_ALERTMODE,
	1,	 "EMULATIONMODE",		INFO_MAPPED,	FALSE,	EmulationMappings,	ATTR_PREFS_TERMINAL_EMULATIONMODE,
	1,	 "FONTMODE",			INFO_MAPPED,	FALSE,	FontMappings,		ATTR_PREFS_TERMINAL_FONTMODE,
	1,	 "SENDCRMODE",			INFO_MAPPED,	FALSE,	CRMappings,		ATTR_PREFS_TERMINAL_SENDCRMODE,
	1,	 "SENDLFMODE",			INFO_MAPPED,	FALSE,	LFMappings,		ATTR_PREFS_TERMINAL_SENDLFMODE,
	1,	 "RECEIVECRMODE",		INFO_MAPPED,	FALSE,	CRMappings,		ATTR_PREFS_TERMINAL_RECEIVECRMODE,
	1,	 "RECEIVELFMODE",		INFO_MAPPED,	FALSE,	LFMappings,		ATTR_PREFS_TERMINAL_RECEIVELFMODE,
	1,	 "NUMCOLUMNS",			INFO_NUMERIC,	FALSE,	NULL,			ATTR_PREFS_TERMINAL_NUMCOLUMNS,
	1,	 "NUMLINES",			INFO_NUMERIC,	FALSE,	NULL,			ATTR_PREFS_TERMINAL_NUMLINES,
	1,	 "KEYMAPNAME",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_TERMINAL_KEYMAPNAME,
	1,	 "EMULATIONNAME",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_TERMINAL_EMULATIONNAME,
	1,	 "FONTNAME",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_TERMINAL_FONTNAME,
	1,	 "FONTSIZE",			INFO_NUMERIC,	FALSE,	NULL,			ATTR_PREFS_TERMINAL_FONTSIZE,

	0,	"PATHPREFS",			INFO_STEM,	FALSE,	NULL,			ATTR_PREFS_PATHS,
	1,	 "ASCIIUPLOADPATH",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_PATHS_ASCIIUPLOADPATH,
	1,	 "ASCIIDOWNLOADPATH",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_PATHS_ASCIIDOWNLOADPATH,
	1,	 "TEXTUPLOADPATH",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_PATHS_TEXTUPLOADPATH,
	1,	 "TEXTDOWNLOADPATH",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_PATHS_TEXTDOWNLOADPATH,
	1,	 "BINARYUPLOADPATH",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_PATHS_BINARYUPLOADPATH,
	1,	 "BINARYDOWNLOADPATH",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_PATHS_BINARYDOWNLOADPATH,
	1,	 "CONFIGPATH",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_PATHS_CONFIGPATH,
	1,	 "EDITORNAME",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_PATHS_EDITORNAME,
	1,	 "HELPFILENAME",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_PATHS_HELPFILENAME,

	0,	"MISCPREFS",			INFO_STEM,	FALSE,	NULL,			ATTR_PREFS_MISC,
	1,	 "PRIORITY",			INFO_NUMERIC,	FALSE,	NULL,			ATTR_PREFS_MISC_PRIORITY,
	1,	 "BACKUPCONFIG",		INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_MISC_BACKUPCONFIG,
	1,	 "OPENFASTMACROPANEL",		INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_MISC_OPENFASTMACROPANEL,
	1,	 "RELEASEDEVICE",		INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_MISC_RELEASEDEVICE,
	1,	 "OVERRIDEPATH",		INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_MISC_OVERRIDEPATH,
	1,	 "AUTOUPLOAD",			INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_MISC_AUTOUPLOAD,
	1,	 "SETARCHIVEDBIT",		INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_MISC_SETARCHIVEDBIT,
	1,	 "COMMENTMODE",			INFO_MAPPED,	FALSE,	IdentifyMappings,	ATTR_PREFS_MISC_COMMENTMODE,
	1,	 "TRANSFERICONS",		INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_MISC_TRANSFERICONS,
	1,	 "CREATEICONS",			INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_MISC_CREATEICONS,
	1,	 "SIMPLEIO",			INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_MISC_SIMPLEIO,
	1,	 "TRANSFERPERFMETER",		INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_MISC_TRANSFER_PERFMETER,

	0,	"CLIPBOARDPREFS",		INFO_STEM,	FALSE,	NULL,			ATTR_PREFS_CLIPBOARD,
	1,	 "UNIT",			INFO_NUMERIC,	FALSE,	NULL,			ATTR_PREFS_CLIPBOARD_UNIT,
	1,	 "LINEDELAY",			INFO_NUMERIC,	FALSE,	NULL,			ATTR_PREFS_CLIPBOARD_LINEDELAY,
	1,	 "CHARDELAY",			INFO_NUMERIC,	FALSE,	NULL,			ATTR_PREFS_CLIPBOARD_CHARDELAY,
	1,	 "INSERTPREFIXTEXT",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_CLIPBOARD_INSERTPREFIXTEXT,
	1,	 "INSERTSUFFIXTEXT",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_CLIPBOARD_INSERTSUFFIXTEXT,
	1,	 "LINEPROMPTTEXT",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_CLIPBOARD_LINEPROMPT,
	1,	 "TEXTPACING",			INFO_MAPPED,	FALSE,	PacingMappings,		ATTR_PREFS_CLIPBOARD_TEXTPACING,
	1,	 "TEXTPACING",			INFO_NUMERIC,	FALSE,	NULL,			ATTR_PREFS_CLIPBOARD_SENDTIMEOUT,

	0,	"CAPTUREPREFS",			INFO_STEM,	FALSE,	NULL,			ATTR_PREFS_CAPTURE,
	1,	 "LOGACTIONS",			INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_CAPTURE_LOGACTIONS,
	1,	 "LOGCALLS",			INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_CAPTURE_LOGCALLS,
	1,	 "LOGFILENAME",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_CAPTURE_LOGFILENAME,
	1,	 "MAXBUFFERSIZE",		INFO_NUMERIC,	FALSE,	NULL,			ATTR_PREFS_CAPTURE_MAXBUFFERSIZE,
	1,	 "BUFFER",			INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_CAPTURE_BUFFER,
	1,	 "CONNECTAUTOCAPTURE",		INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_CAPTURE_CONNECTAUTOCAPTURE,
	1,	 "AUTOCAPTUREDATE",		INFO_MAPPED,	FALSE,	AutoDateMappings,	ATTR_PREFS_CAPTURE_AUTOCAPTUREDATE,
	1,	 "CAPTUREFILTER",		INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_CAPTURE_CAPTUREFILTER,
	1,	 "CAPTUREPATH",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_CAPTURE_CAPTUREPATH,
	1,	 "CALLLOGFILENAME",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_CAPTURE_CALLLOGFILENAME,
	1,	 "BUFFERSAVEPATH",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_CAPTURE_BUFFERSAVEPATH,
	1,	 "OPENBUFFERWINDOW",		INFO_MAPPED,	FALSE,	OpenBufferMappings,	ATTR_PREFS_CAPTURE_OPENBUFFERWINDOW,
	1,	 "OPENBUFFERSCREEN",		INFO_MAPPED,	FALSE,	OpenBufferMappings,	ATTR_PREFS_CAPTURE_OPENBUFFERSCREEN,
	1,	 "BUFFERSCREENPOSITION",	INFO_MAPPED,	FALSE,	BufferPositionMappings,	ATTR_PREFS_CAPTURE_BUFFERSCREENPOSITION,
	1,	 "BUFFERWIDTH",			INFO_NUMERIC,	FALSE,	NULL,			ATTR_PREFS_CAPTURE_BUFFERWIDTH,
	1,	 "REMEMBERBUFFERWINDOW",	INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_CAPTURE_REMEMBER_BUFFERWINDOW,
	1,	 "REMEMBERBUFFERSCREEN",	INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_CAPTURE_REMEMBER_BUFFERSCREEN,

	0,	"FILEPREFS",			INFO_STEM,	FALSE,	NULL,			ATTR_PREFS_FILE,
	1,	 "TRANSFERPROTOCOLNAME",	INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_FILE_TRANSFERPROTOCOLNAME,
	1,	 "TRANSLATIONFILENAME",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_FILE_TRANSLATIONFILENAME,
	1,	 "MACROFILENAME",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_FILE_MACROFILENAME,
	1,	 "CURSORFILENAME",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_FILE_CURSORFILENAME,
	1,	 "FASTMACROFILENAME",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_FILE_FASTMACROFILENAME,

	0,	"EMULATIONPREFS",		INFO_STEM,	FALSE,	NULL,			ATTR_PREFS_EMULATION,
	1,	 "CURSORMODE",			INFO_MAPPED,	FALSE,	ApplicationMappings,	ATTR_PREFS_EMULATION_CURSORMODE,
	1,	 "NUMERICMODE",			INFO_MAPPED,	FALSE,	ApplicationMappings,	ATTR_PREFS_EMULATION_NUMERICMODE,
	1,	 "CURSORWRAP",			INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_EMULATION_CURSORWRAP,
	1,	 "LINEWRAP",			INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_EMULATION_LINEWRAP,
	1,	 "INSERTMODE",			INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_EMULATION_INSERTMODE,
	1,	 "NEWLINEMODE",			INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_EMULATION_NEWLINEMODE,
	1,	 "FONTSCALEMODE",		INFO_MAPPED,	FALSE,	FontScaleMappings,	ATTR_PREFS_EMULATION_FONTSCALEMODE,
	1,	 "SCROLLMODE",			INFO_MAPPED,	FALSE,	ScrollMappings,		ATTR_PREFS_EMULATION_SCROLLMODE,
	1,	 "DESTRUCTIVEBACKSPACE",	INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_EMULATION_DESTRUCTIVEBACKSPACE,
	1,	 "SWAPBSDELETE",		INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_EMULATION_SWAPBSDELETE,
	1,	 "PRINTERENABLED",		INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_EMULATION_PRINTERENABLED,
	1,	 "ANSWERBACKTEXT",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_EMULATION_ANSWERBACKTEXT,
	1,	 "CLSRESETSCURSOR",		INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_EMULATION_CLS_RESETS_CURSOR,

	0,	"TRANSFERPREFS",		INFO_STEM,	FALSE,	NULL,			ATTR_PREFS_TRANSFER,
	1,	 "DEFAULTLIBRARY",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_TRANSFER_DEFAULT_LIBRARY,
	1,	 "ASCIIUPLOADLIBRARY",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_TRANSFER_ASCII_UPLOAD_LIBRARY,
	1,	 "INTERNALASCIIUPLOAD",		INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_TRANSFER_INTERNAL_ASCII_UPLOAD,
	1,	 "ASCIIDOWNLOADLIBRARY",	INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_TRANSFER_ASCII_DOWNLOAD_LIBRARY,
	1,	 "INTERNALASCIIDOWNLOAD",	INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_TRANSFER_INTERNAL_ASCII_DOWNLOAD,
	1,	 "QUIETTRANSFER",		INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_TRANSFER_QUIET_TRANSFER,
	1,	 "TEXTUPLOADLIBRARY",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_TRANSFER_TEXT_UPLOAD_LIBRARY,
	1,	 "TEXTDOWNLOADLIBRARY",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_TRANSFER_TEXT_DOWNLOAD_LIBRARY,
	1,	 "BINARYUPLOADLIBRARY",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_TRANSFER_BINARY_UPLOAD_LIBRARY,
	1,	 "BINARYDOWNLOADLIBRARY",	INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_TRANSFER_BINARY_DOWNLOAD_LIBRARY,

	0,	"SPEECHPREFS",			INFO_STEM,	FALSE,	NULL,			ATTR_PREFS_SPEECH,
	1,	 "RATE",			INFO_NUMERIC,	FALSE,	NULL,			ATTR_PREFS_SPEECH_RATE,
	1,	 "PITCH",			INFO_NUMERIC,	FALSE,	NULL,			ATTR_PREFS_SPEECH_PITCH,
	1,	 "FREQUENCY",			INFO_NUMERIC,	FALSE,	NULL,			ATTR_PREFS_SPEECH_FREQUENCY,
	1,	 "SEXMODE",			INFO_MAPPED,	FALSE,	SexMappings,		ATTR_PREFS_SPEECH_SEXMODE,
	1,	 "VOLUME",			INFO_NUMERIC,	FALSE,	NULL,			ATTR_PREFS_SPEECH_VOLUME,
	1,	 "SPEECH",			INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_SPEECH_SPEECH,

	0,	"TRANSLATIONPREFS",		INFO_STEM,	FALSE,	NULL,			ATTR_PREFS_TRANSLATIONS,
	1,	 NULL,				INFO_STEM,	FALSE,	NULL,			ATTR_PREFS_TRANSLATIONS_X,
	2,	 "SEND",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_TRANSLATIONS_X_SEND,
	2,	 "RECEIVE",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_TRANSLATIONS_X_RECEIVE,

	0,	"FASTMACROPREFS",		INFO_STEM,	FALSE,	NULL,			ATTR_PREFS_FASTMACROS,
	1,	 "COUNT",			INFO_NUMERIC,	FALSE,	NULL,			ATTR_PREFS_FASTMACROS_COUNT,
	1,	  NULL,				INFO_STEM,	FALSE,	NULL,			ATTR_PREFS_FASTMACROS_X,
	2,	  "NAME",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_FASTMACROS_X_NAME,
	2,	  "CODE",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_FASTMACROS_X_CODE,

	0,	"HOTKEYPREFS",			INFO_STEM,	FALSE,	NULL,			ATTR_PREFS_HOTKEYS,
	1,	 "TERMSCREENTOFRONTTEXT",	INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_HOTKEYS_TERMSCREENTOFRONTTEXT,
	1,	 "BUFFERSCREENTOFRONTTEXT",	INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_HOTKEYS_BUFFERSCREENTOFRONTTEXT,
	1,	 "SKIPDIALENTRYTEXT",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_HOTKEYS_SKIPDIALENTRYTEXT,
	1,	 "ABORTAREXX",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_HOTKEYS_ABORTAREXX,
	1,	 "COMMODITYPRIORITY",		INFO_NUMERIC,	FALSE,	NULL,			ATTR_PREFS_HOTKEYS_COMMODITYPRIORITY,
	1,	 "HOTKEYSENABLED",		INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_HOTKEYS_HOTKEYSENABLED,

	0,	"CURSORKEYPREFS",		INFO_STEM,	FALSE,	NULL,			ATTR_PREFS_CURSORKEYS,
	1,	 "UPTEXT",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_CURSORKEYS_UPTEXT,
	1,	 "RIGHTTEXT",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_CURSORKEYS_RIGHTTEXT,
	1,	 "DOWNTEXT",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_CURSORKEYS_DOWNTEXT,
	1,	 "LEFTTEXT",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_CURSORKEYS_LEFTTEXT,

	1,	 "SHIFT",			INFO_STEM,	FALSE,	NULL,			ATTR_PREFS_CURSORKEYS_SHIFT,
	2,	  "UPTEXT",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_CURSORKEYS_SHIFT_UPTEXT,
	2,	  "RIGHTTEXT",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_CURSORKEYS_SHIFT_RIGHTTEXT,
	2,	  "DOWNTEXT",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_CURSORKEYS_SHIFT_DOWNTEXT,
	2,	  "LEFTTEXT",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_CURSORKEYS_SHIFT_LEFTTEXT,

	1,	 "ALT",				INFO_STEM,	FALSE,	NULL,			ATTR_PREFS_CURSORKEYS_ALT,
	2,	  "UPTEXT",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_CURSORKEYS_ALT_UPTEXT,
	2,	  "RIGHTTEXT",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_CURSORKEYS_ALT_RIGHTTEXT,
	2,	  "DOWNTEXT",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_CURSORKEYS_ALT_DOWNTEXT,
	2,	  "LEFTTEXT",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_CURSORKEYS_ALT_LEFTTEXT,

	1,	 "CONTROL",			INFO_STEM,	FALSE,	NULL,			ATTR_PREFS_CURSORKEYS_CONTROL,
	2,	  "UPTEXT",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_CURSORKEYS_CONTROL_UPTEXT,
	2,	  "RIGHTTEXT",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_CURSORKEYS_CONTROL_RIGHTTEXT,
	2,	  "DOWNTEXT",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_CURSORKEYS_CONTROL_DOWNTEXT,
	2,	  "LEFTTEXT",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_CURSORKEYS_CONTROL_LEFTTEXT,

	0,	"FUNCTIONKEYPREFS",		INFO_STEM,	FALSE,	NULL,			ATTR_PREFS_FUNCTIONKEYS,
	1,	  NULL,				INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_FUNCTIONKEYS_X,
	1,	 "SHIFT",			INFO_STEM,	FALSE,	NULL,			ATTR_PREFS_FUNCTIONKEYS_SHIFT,
	2,	   NULL,			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_FUNCTIONKEYS_SHIFT_X,
	1,	 "ALT",				INFO_STEM,	FALSE,	NULL,			ATTR_PREFS_FUNCTIONKEYS_ALT,
	2,	   NULL,			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_FUNCTIONKEYS_ALT_X,
	1,	 "CONTROL",			INFO_STEM,	FALSE,	NULL,			ATTR_PREFS_FUNCTIONKEYS_CONTROL,
	2,	   NULL,			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_FUNCTIONKEYS_CONTROL_X,

	0,	"PROTOCOLPREFS",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_PROTOCOL,

	0,	"CONSOLEPREFS",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_CONSOLE,

	0,	"SOUNDPREFS",			INFO_STEM,	FALSE,	NULL,			ATTR_PREFS_SOUND,
	1,	 "BELLNAME",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_SOUND_BELLNAME,
	1,	 "CONNECTNAME",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_SOUND_CONNECTNAME,
	1,	 "DISCONNECTNAME",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_SOUND_DISCONNECTNAME,
	1,	 "GOODTRANSFERNAME",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_SOUND_GOODTRANSFERNAME,
	1,	 "BADTRANSFERNAME",		INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_SOUND_BADTRANSFERNAME,
	1,	 "RINGNAME",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_SOUND_RINGNAME,
	1,	 "VOICENAME",			INFO_TEXT,	FALSE,	NULL,			ATTR_PREFS_SOUND_VOICENAME,
	1,	 "PRELOAD",			INFO_BOOLEAN,	FALSE,	NULL,			ATTR_PREFS_SOUND_PRELOAD,

	0,	"PHONEBOOK",			INFO_STEM,	TRUE,	NULL,			ATTR_PHONEBOOK,

	1,	 "COUNT",			INFO_NUMERIC,	TRUE,	NULL,			ATTR_PHONEBOOK_COUNT,
	1,	  NULL,				INFO_STEM,	TRUE,	NULL,			ATTR_PHONEBOOK_X,
	2,	  "NAME",			INFO_TEXT,	TRUE,	NULL,			ATTR_PHONEBOOK_X_NAME,
	2,	  "NUMBER",			INFO_TEXT,	TRUE,	NULL,			ATTR_PHONEBOOK_X_NUMBER,
	2,	  "COMMENTTEXT",		INFO_TEXT,	TRUE,	NULL,			ATTR_PHONEBOOK_X_COMMENTTEXT,
	2,	  "USERNAME",			INFO_TEXT,	TRUE,	NULL,			ATTR_PHONEBOOK_X_USERNAME,
	2,	  "PASSWORDTEXT",		INFO_TEXT,	TRUE,	NULL,			ATTR_PHONEBOOK_X_PASSWORDTEXT
};

LONG AttributeTableSize = sizeof(AttributeTable) / sizeof(struct AttributeEntry);

	/* Information on arguments to exclude each other.*/

STATIC struct ExclusionInfo ExclusionInfoTable_00[] =
{
	1,2, 3,4, -1,-1
};

STATIC struct ExclusionInfo ExclusionInfoTable_01[] =
{
	0,1, -1,-1
};

STATIC struct ExclusionInfo ExclusionInfoTable_02[] =
{
	2,3, -1,-1
};

STATIC struct ExclusionInfo ExclusionInfoTable_03[] =
{
	0,1, 0,2, 0,3, 0,4, 1,2, 1,3, 1,4, 2,3, 2,4, 3,4, -1,-1
};

STATIC struct ExclusionInfo ExclusionInfoTable_04[] =
{
	0,1, 0,2, 1,2, -1,-1
};

STATIC struct ExclusionInfo ExclusionInfoTable_05[] =
{
	0,2, 0,3, 0,4, 0,5, 2,3, 2,4, 2,5, 3,4, 3,5, 4,5, -1,-1
};

STATIC struct ExclusionInfo ExclusionInfoTable_06[] =
{
	2,3, -1,-1
};

STATIC struct ExclusionInfo ExclusionInfoTable_07[] =
{
	0,1, -1,-1
};

STATIC struct ExclusionInfo ExclusionInfoTable_08[] =
{
	0,1, -1,-1
};

STATIC struct ExclusionInfo ExclusionInfoTable_09[] =
{
	0,1, -1,-1
};

STATIC struct ExclusionInfo ExclusionInfoTable_10[] =
{
	1,2, 2,3, 2,4, 2,5, 2,6, 2,7, 2,8, 2,9, 2,10, 2,11, 4,5, 6,7, 8,9, 8,10, 8,11, 9,10, 9,11, 10,11, -1,-1
};

	/* This is where the information on what arguments exclude
	 * other arguments is linked to the actual commands.
	 */

struct ExclusionInfo *ExclusionTable[] =
{
	/* ACTIVATE */		NULL,
	/* ADD */		ExclusionInfoTable_00,
	/* BAUD */		NULL,
	/* BEEPSCREEN */	NULL,
	/* CALLMENU */		NULL,
	/* CAPTURE */		NULL,
	/* CLEAR */		NULL,
	/* CLEARSCREEN */	NULL,
	/* CLOSE */		NULL,
	/* CLOSEDEVICE */	NULL,
	/* CLOSEREQUESTER */	NULL,
	/* DEACTIVATE */	NULL,
	/* DELAY */		NULL,
	/* DIAL */		NULL,
	/* DUPLEX */		ExclusionInfoTable_01,
	/* EXECTOOL */		NULL,
	/* FAULT */		NULL,
	/* GETATTR */		ExclusionInfoTable_02,
	/* GETCLIP */		NULL,
	/* HANGUP */		NULL,
	/* HELP */		NULL,
	/* OPEN */		NULL,
	/* OPENDEVICE */	NULL,
	/* OPENREQUESTER */	NULL,
	/* PARITY */		ExclusionInfoTable_03,
	/* PASTECLIP */		NULL,
	/* PRINT */		NULL,
	/* PROTOCOL */		ExclusionInfoTable_04,
	/* PUTCLIP */		NULL,
	/* QUIT */		NULL,
	/* READ */		ExclusionInfoTable_01,
	/* RECEIVEFILE */	NULL,
	/* REDIAL */		NULL,
	/* REMOVE */		NULL,
	/* REQUESTFILE */	NULL,
	/* REQUESTNOTIFY */	NULL,
	/* REQUESTNUMBER */	NULL,
	/* REQUESTRESPONSE */	NULL,
	/* REQUESTSTRING */	NULL,
	/* RESETSCREEN */	NULL,
	/* RESETSTYLES */	NULL,
	/* RESETTEXT */		NULL,
	/* RX */		NULL,
	/* SAVE */		NULL,
	/* SAVEAS */		NULL,
	/* SELECTITEM */	ExclusionInfoTable_05,
	/* SEND */		NULL,
	/* SENDBREAK */		NULL,
	/* SENDFILE */		NULL,
	/* SETATTR */		ExclusionInfoTable_06,
	/* SPEAK */		NULL,
	/* STOPBITS */		ExclusionInfoTable_07,
	/* TEXTBUFFER */	ExclusionInfoTable_08,
	/* TIMEOUT */		ExclusionInfoTable_09,
	/* WAIT */		NULL,
	/* WINDOW */		ExclusionInfoTable_10,
};

	/* This is where the information on which arguments (switches and keywords)
	 * are actually required is stored.
	 */

UWORD InclusionTable[] =
{
	/* ACTIVATE */		NULL,
	/* ADD */		INCLUDE_03|INCLUDE_04,
	/* BAUD */		NULL,
	/* BEEPSCREEN */	NULL,
	/* CALLMENU */		NULL,
	/* CAPTURE */		NULL,
	/* CLEAR */		NULL,
	/* CLEARSCREEN */	NULL,
	/* CLOSE */		NULL,
	/* CLOSEDEVICE */	NULL,
	/* CLOSEREQUESTER */	NULL,
	/* DEACTIVATE */	NULL,
	/* DELAY */		INCLUDE_00|INCLUDE_01|INCLUDE_02,
	/* DIAL */		NULL,
	/* DUPLEX */		INCLUDE_00|INCLUDE_01,
	/* EXECTOOL */		NULL,
	/* FAULT */		NULL,
	/* GETATTR */		NULL,
	/* GETCLIP */		NULL,
	/* HANGUP */		NULL,
	/* HELP */		INCLUDE_00|INCLUDE_01,
	/* OPEN */		NULL,
	/* OPENDEVICE */	NULL,
	/* OPENREQUESTER */	NULL,
	/* PARITY */		INCLUDE_00|INCLUDE_01|INCLUDE_02|INCLUDE_03|INCLUDE_04,
	/* PASTECLIP */		NULL,
	/* PRINT */		NULL,
	/* PROTOCOL */		INCLUDE_00|INCLUDE_01|INCLUDE_02,
	/* PUTCLIP */		NULL,
	/* QUIT */		NULL,
	/* READ */		INCLUDE_00|INCLUDE_01,
	/* RECEIVEFILE */	NULL,
	/* REDIAL */		NULL,
	/* REMOVE */		NULL,
	/* REQUESTFILE */	NULL,
	/* REQUESTNOTIFY */	NULL,
	/* REQUESTNUMBER */	NULL,
	/* REQUESTRESPONSE */	NULL,
	/* REQUESTSTRING */	NULL,
	/* RESETSCREEN */	NULL,
	/* RESETSTYLES */	NULL,
	/* RESETTEXT */		NULL,
	/* RX */		NULL,
	/* SAVE */		NULL,
	/* SAVEAS */		INCLUDE_00|INCLUDE_02|INCLUDE_03|INCLUDE_04|INCLUDE_05,
	/* SELECTITEM */	NULL,
	/* SEND */		INCLUDE_02|INCLUDE_03,
	/* SENDBREAK */		NULL,
	/* SENDFILE */		NULL,
	/* SETATTR */		INCLUDE_02|INCLUDE_03,
	/* SPEAK */		NULL,
	/* STOPBITS */		INCLUDE_00|INCLUDE_01,
	/* TEXTBUFFER */	INCLUDE_00|INCLUDE_01,
	/* TIMEOUT */		INCLUDE_00|INCLUDE_01,
	/* WAIT */		NULL,
	/* WINDOW */		INCLUDE_01|INCLUDE_02|INCLUDE_03|INCLUDE_04|INCLUDE_05|INCLUDE_06|INCLUDE_07|INCLUDE_08|INCLUDE_09|INCLUDE_10|INCLUDE_11,
};

	/* This is where command names, arguments and the routines
	 * to execute the actual commands are linked together.
	 */

struct CommandInfo CommandTable[] =
{
	TRUE,	FALSE,	FALSE,	RexxActivate,		"ACTIVATE",		 NULL,
	FALSE,	FALSE,	FALSE,	RexxAdd,		"ADDITEM",		"TO/A,BEFORE/S,AFTER/S,PHONE/K/F,NAME/K/F",
	FALSE,	FALSE,	FALSE,	RexxBaud,		"BAUD",			"RATE/A/N",
	FALSE,	FALSE,	FALSE,	RexxBeepScreen,		"BEEPSCREEN",		 NULL,
	FALSE,	FALSE,	FALSE,	RexxCallMenu,		"CALLMENU",		"TITLE/A/F",
	FALSE,	FALSE,	FALSE,	RexxCapture,		"CAPTURE",		"TO/A,NAME/K",
	FALSE,	FALSE,	FALSE,	RexxClear,		"CLEAR",		"FROM/A,FORCE/S",
	FALSE,	FALSE,	FALSE,	RexxClearScreen,	"CLEARSCREEN",		 NULL,
	FALSE,	FALSE,	FALSE,	RexxClose,		"CLOSE",		"FROM/A",
	FALSE,	FALSE,	FALSE,	RexxCloseDevice,	"CLOSEDEVICE",		 NULL,
	TRUE,	FALSE,	FALSE,	RexxCloseRequester,	"CLOSEREQUESTER",	 NULL,
	FALSE,	FALSE,	FALSE,	RexxDeactivate,		"DEACTIVATE",		 NULL,
	FALSE,	FALSE,	FALSE,	RexxDelay,		"DELAY",		"MIC=MICROSECONDS/K/N,SEC=SECONDS/N,MIN=MINUTES/K/N,QUIET/S",
	FALSE,	FALSE,	FALSE,	RexxDial,		"DIAL",			"NUM/F",
	FALSE,	FALSE,	FALSE,	RexxDuplex,		"DUPLEX",		"FULL/S,HALF=ECHO/S",
	TRUE,	TRUE,	TRUE,	RexxExecTool,		"EXECTOOL",		"CONSOLE/S,ASYNC/S,PORT/S,COMMAND/A/F",
	TRUE,	FALSE,	FALSE,	RexxFault,		"FAULT",		"CODE/A/N",
	FALSE,	FALSE,	FALSE,	RexxGetAttr,		"GETATTR",		"OBJECT/A,FIELD,STEM/K,VAR/K",
	FALSE,	FALSE,	FALSE,	RexxGetClip,		"GETCLIP",		"UNIT/K/N",
	FALSE,	FALSE,	FALSE,	RexxHangup,		"HANGUP",		 NULL,
	TRUE,	FALSE,	FALSE,	RexxHelp,		"HELP",			"COMMAND,PROMPT/S",
	FALSE,	FALSE,	FALSE,	RexxOpen,		"OPEN",			"NAME/K,TO/A",
	FALSE,	FALSE,	FALSE,	RexxOpenDevice,		"OPENDEVICE",		"NAME/K,UNIT/K/N",
	FALSE,	FALSE,	FALSE,	RexxOpenRequester,	"OPENREQUESTER",	"REQUESTER/A",
	FALSE,	FALSE,	FALSE,	RexxParity,		"PARITY",		"EVEN/S,ODD/S,NONE/S,MARK/S,SPACE/S",
	FALSE,	FALSE,	FALSE,	RexxPasteClip,		"PASTECLIP",		"UNIT/K/N",
	FALSE,	FALSE,	FALSE,	RexxPrint,		"PRINT",		"FROM/A,TO/K,SERIAL/S,MODEM/S,SCREEN/S,TERMINAL/S,USER/S,COMMENT/S,SIZE/S,DATE/S,ATTR/S",
	FALSE,	FALSE,	FALSE,	RexxProtocol,		"PROTOCOL",		"NONE/S,RTSCTS/S,RTSCTSDTR/S",
	FALSE,	FALSE,	FALSE,	RexxPutClip,		"PUTCLIP",		"UNIT/K/N,TEXT/A/F",
	FALSE,	FALSE,	FALSE,	RexxQuit,		"QUIT",			"FORCE/S",
	FALSE,	FALSE,	FALSE,	RexxRead,		"READ",			"NUM/K/N,CR/S,NOECHO/S,VERBATIM/S,PROMPT/K/F",
	FALSE,	FALSE,	FALSE,	RexxReceiveFile,	"RECEIVEFILE",		"MODE/K,NAME/K",
	FALSE,	FALSE,	FALSE,	RexxRedial,		"REDIAL",		 NULL,
	TRUE,	FALSE,	FALSE,	RexxRemove,		"REMITEM",		"FROM/A,NAME/K/F",
	FALSE,	FALSE,	FALSE,	RexxRequestFile,	"REQUESTFILE",		"TITLE/K,PATH/K,FILE/K,PATTERN/K,MULTI/S,STEM=NAME/K",
	FALSE,	FALSE,	FALSE,	RexxRequestNotify,	"REQUESTNOTIFY",	"TITLE/K,PROMPT/A/F",
	FALSE,	FALSE,	FALSE,	RexxRequestNumber,	"REQUESTNUMBER",	"DEFAULT/K/N,PROMPT/K/F",
	FALSE,	FALSE,	FALSE,	RexxRequestResponse,	"REQUESTRESPONSE",	"TITLE/K,OPTIONS/K,PROMPT/A/F",
	FALSE,	FALSE,	FALSE,	RexxRequestString,	"REQUESTSTRING",	"SECRET/S,DEFAULT/K,PROMPT/K/F",
	FALSE,	FALSE,	FALSE,	RexxResetScreen,	"RESETSCREEN",		 NULL,
	FALSE,	FALSE,	FALSE,	RexxResetStyles,	"RESETSTYLES",		 NULL,
	FALSE,	FALSE,	FALSE,	RexxResetText,		"RESETTEXT",		 NULL,
	TRUE,	TRUE,	TRUE,	RexxRX,			"RX",			"CONSOLE/S,ASYNC/S,COMMAND/A/F",
	FALSE,	FALSE,	FALSE,	RexxSave,		"SAVE",			"FROM/A",
	FALSE,	FALSE,	FALSE,	RexxSaveAs,		"SAVEAS",		"NAME/K,FROM/A",
	TRUE,	FALSE,	FALSE,	RexxSelect,		"SELECTITEM",		"NAME/K,FROM/A,NEXT/S,PREV=PREVIOUS/S,TOP/S,BOTTOM/S",
	FALSE,	FALSE,	FALSE,	RexxSend,		"SEND",			"NOECHO/S,LOCAL/S,BYTE/K/N,TEXT/F",
	FALSE,	FALSE,	FALSE,	RexxSendBreak,		"SENDBREAK",		 NULL,
	FALSE,	FALSE,	FALSE,	RexxSendFile,		"SENDFILE",		"MODE/K,NAMES/M",
	FALSE,	FALSE,	FALSE,	RexxSetAttr,		"SETATTR",		"OBJECT/A,FIELD,STEM/K,VAR",
	TRUE,	FALSE,	FALSE,	RexxSpeak,		"SPEAK",		"TEXT/A/F",
	FALSE,	FALSE,	FALSE,	RexxStopBits,		"STOPBITS",		"0/S,1/S",
	FALSE,	FALSE,	FALSE,	RexxTextBuffer,		"TEXTBUFFER",		"LOCK/S,UNLOCK/S",
	FALSE,	FALSE,	FALSE,	RexxTimeout,		"TIMEOUT",		"SEC=SECONDS/N,OFF/S",
	FALSE,	FALSE,	FALSE,	RexxWait,		"WAIT",			"NOECHO/S,TEXT/F",
	FALSE,	FALSE,	FALSE,	RexxWindow,		"WINDOW",		"NAMES/A/M,OPEN/S,CLOSE/S,ACTIVATE/S,MIN/S,MAX/S,FRONT/S,BACK/S,TOP/S,BOTTOM/S,UP/S,DOWN/S",
};

LONG CommandTableSize = sizeof(CommandTable) / sizeof(struct CommandInfo);

struct MsgPort		*RexxPort		= NULL;
LONG			 LastRexxError		= 0;
LONG			 RexxTimeoutVal		= 0;
BYTE			 UpdateRequired		= FALSE,
			 TransferUpdateRequired	= FALSE;

LONG			 RexxLaunchCount	= 0;
struct SignalSemaphore	 RexxLaunchSemaphore;
